@@ -58,12 +58,12 @@ __all__ = [
     "ExtractMetaCallback",
 ]
 
+import cv2
+import numpy
 import typing as _typing
 import cv2.gapi.wip.draw
-import cv2.mat_wrapper
 import cv2.dnn
-import numpy
-import cv2
+import cv2.mat_wrapper
 
 
 if _typing.TYPE_CHECKING:
@@ -98,8 +98,8 @@ Size = _typing.Sequence[int]
 """Required length is 2"""
 Size2f = _typing.Sequence[float]
 """Required length is 2"""
-Scalar = _typing.Sequence[float]
-"""Required length is at most 4"""
+Scalar = _typing.Union[_typing.Sequence[float], float]
+"""Max sequence length is at most 4"""
 Point = _typing.Sequence[int]
 """Required length is 2"""
 Point2i = Point
